import { MindNodeModel } from "./MindNodeModel";
import { MindMapModel } from "./MindMapModel";
import { FocusItemMode, NodeKeyType } from "../types/Node";
import { Stack } from "immutable";
import { NodeRelationship } from "./NodeRelationship";
export declare enum OpType {
    UNDO = 1,
    REDO = 2,
    TOGGLE_COLLAPSE = 3,
    SET_ITEM_CONTENT = 4,
    SET_ITEM_DESC = 5,
    FOCUS_ITEM = 6,
    SET_EDIT_ITEM_KEY = 7,
    SET_FOCUS_ITEM_MODE = 8,
    SET_POPUP_MENU_ITEM_KEY = 9,
    ADD_CHILD = 10,
    ADD_SIBLING = 11,
    DELETE_NODE = 12,
    DRAG_AND_DROP = 13
}
declare type OpFunctionType = (model: MindMapModel, itemKey: NodeKeyType, arg?: any) => MindMapModel;
export declare class MindMapModelModifier {
    static undoStack: Stack<MindMapModel>;
    static redoStack: Stack<MindMapModel>;
    static opMap: Map<OpType, OpFunctionType>;
    static op(model: MindMapModel, opType: OpType, itemKey: NodeKeyType, arg: any): MindMapModel;
    static undo(model: MindMapModel): MindMapModel;
    static redo(model: MindMapModel): MindMapModel;
    static pushUndoStack(model: MindMapModel): void;
    static popUndoStack(): MindMapModel;
    static pushRedoStack(model: MindMapModel): void;
    static popRedoStack(): MindMapModel;
    static toggleCollapse(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static setItem(model: MindMapModel, item: MindNodeModel): MindMapModel;
    static focusItem(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static setFocusItemMode(model: MindMapModel, itemKey: NodeKeyType, mode: FocusItemMode): MindMapModel;
    static setEditingItemKey(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static setPopupMenuItemKey(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static setItemContent(model: MindMapModel, itemKey: NodeKeyType, content: any): MindMapModel;
    static setItemDesc(model: MindMapModel, itemKey: NodeKeyType, desc: any): MindMapModel;
    static addChild(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static addSibling(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static deleteNode(model: MindMapModel, itemKey: NodeKeyType): MindMapModel;
    static getAllSubItemKeys(model: MindMapModel, itemKey: NodeKeyType): any[];
    static getRelation(model: MindMapModel, srcKey: NodeKeyType, dstKey: NodeKeyType): NodeRelationship;
    static dragAndDrop(model: MindMapModel, srcKey: NodeKeyType, dstKey: NodeKeyType): MindMapModel;
}
export {};
